@@ -5,4 +5,4 @@ globalVariables(c("zone", "region", "parent_class", "child_class",
   "child_collection", "is_summary", "count_band", "count_sample",
   "count_timeslice", "filename", "scenario", "key", "value",
   "interval_id", "interval_to_id", "db", "period_id", "time_from",
-  "time_to"))
+  "time_to", "Version", "rplexos", "d", "error", "interval"))
